#!/usr/bin/env bash

type fig >/dev/null || (echo "ERROR: fig not found, aborting" && exit 1)
fig_demo() { fig --parlare 1 --light-run --stop-time 7s $@; }

fig;
sleep 2;

###############################################
echo; echo "--------------------------------";
echo "Tandem queue"; echo "--";

echo; echo "----------------"; echo "Crude Monte Carlo"; echo "--";
fig_demo tandem_queue.sa --cmc;
sleep 2;

echo; echo "----------------"; echo "RES: automatic monolithic"; echo "--";
fig_demo tandem_queue.sa --amono;
sleep 2;

echo; echo "----------------"; echo "RES: automatic monolithic (FE)"; echo "--";
fig_demo tandem_queue.sa --amono -e sfe;
sleep 2;

###############################################
echo; echo "--------------------------------";
echo "Forked-cycle tandem queue"; echo "--";

echo; echo "----------------"; echo "Crude Monte Carlo"; echo "--";
fig_demo forked_cycle_tandem_queue.sa --cmc;
sleep 2;

echo; echo "----------------"; echo "RES: automatic monolithic"; echo "--";
fig_demo forked_cycle_tandem_queue.sa --amono;
sleep 2;

echo; echo "----------------"; echo "RES: automatic compositional"; echo "--";
fig_demo forked_cycle_tandem_queue.sa --acomp +;
sleep 2;

###############################################
echo; echo "--------------------------------";
echo "7-nodes network"; echo "--";

echo; echo "----------------"; echo "Crude Monte Carlo"; echo "--";
fig_demo 7nodes_network_nonJackson.sa --cmc;
sleep 2;

echo; echo "----------------"; echo "RES: automatic compositional"; echo "--";
fig_demo 7nodes_network_nonJackson.sa --acomp +;
sleep 2;

###############################################
echo; echo "--------------------------------";
echo "HECS-3"; echo "--";

./ft2sa HECS_3.{ft,sa} -s -i STR -f;
colordiff HECS_3{,_ava}.sa;

echo; echo "----------------"; echo "Crude Monte Carlo"; echo "--";
fig_demo HECS_3_ava.sa --cmc;
sleep 2;

echo; echo "----------------"; echo "RES: automatic compositional (FT)"; echo "--";
IFUN="'`tail -n 1 HECS_3_ava.sa | awk '{ print $4 }'`'";
fig_demo HECS_3_ava.sa --ft --acomp $IFUN;
sleep 2;

exit 0;
